@@ -1,7 +1,7 @@
 from django.core.exceptions import ValidationError
 from django.db import models
 from django.utils import simplejson as json
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _
 
 from decimal import Decimal
 import datetime
